package core

import (
	"time"

	log "github.com/sirupsen/logrus"
)

// UpdateContractAddressJob 定时更新合约内的地址
func (w *Witness) UpdateContractAddressJob() {
	ticker := time.NewTicker(time.Minute * 10)
	defer ticker.Stop()
	log.Info("start update address task")
	for {
		addrs, err := w.rpc.GetContainerAddresses()
		if err != nil {
			log.WithError(err).Error("failed to get container addresses")
		} else {
			w.containerAddresses = addrs
		}
		addrs, err = w.rpc.GetNMAddresses()
		if err != nil {
			log.WithError(err).Error("failed to get NM addresses")
		} else {
			w.nmAddresses = addrs
		}
		log.WithFields(log.Fields{
			"container_count": len(w.containerAddresses),
			"nm_count":        len(w.nmAddresses),
		}).Info("store contract update address")
		<-ticker.C
	}
}

// UpdateGlobalWorkloadJob 定时从quest更新全局workload
func (w *Witness) UpdateGlobalWorkloadJob() {
	ticker := time.NewTicker(time.Second * 30)
	defer ticker.Stop()
	log.Info("start update global workload task")
	for {
		wl := w.GetGlobalWorkload()
		if wl > 0 {
			w.pendingWorkload = wl
		}
		<-ticker.C
	}
}
